define(
//begin v1.x content
({
	insertTableTitle: "Insertar tabla",
	modifyTableTitle: "Modificar tabla",
	rows: "Filas:",
	columns: "Columnas:",
	align: "Alinear:",
	cellPadding: "Relleno de celda:",
	cellSpacing: "Espaciado de celda:",
	tableWidth: "Ancho de tabla:",
	backgroundColor: "Color de fondo:",
	borderColor: "Color de borde:",
	borderThickness: "Ancho de borde",
	percent: "por ciento",
	pixels: "píxeles",
	"default": "default",
	left: "izquierda",
	center: "centro",
	right: "derecha",
	buttonSet: "Establecer", // translated elsewhere?
	buttonInsert: "Insertar",
	buttonCancel: "Cancelar",

	selectTableLabel: "Seleccionar tabla",
	insertTableRowBeforeLabel: "Añadir fila antes",
	insertTableRowAfterLabel: "Añadir fila después",
	insertTableColumnBeforeLabel: "Añadir columna antes",
	insertTableColumnAfterLabel: "Añadir columna después",
	deleteTableRowLabel: "Suprimir fila",
	deleteTableColumnLabel: "Suprimir columna"
})
	

//end v1.x content
);
